@@ -21,25 +21,18 @@
  * SPDX-License-Identifier: curl
  *
  ***************************************************************************/
-
 #include "curl_setup.h"
 
-#include <curl/curl.h>
-
 #include "urldata.h"
 #include "url.h"
 #include "cfilters.h"
 #include "curl_trc.h"
 #include "multiif.h"
-#include "curlx/timeval.h"
 #include "multi_ev.h"
 #include "select.h"
 #include "uint-bset.h"
 #include "uint-spbset.h"
-#include "uint-table.h"
-#include "curlx/warnless.h"
 #include "multihandle.h"
-#include "socks.h"
 
 
 static void mev_in_callback(struct Curl_multi *multi, bool value)
@@ -348,7 +341,7 @@ static CURLMcode mev_pollset_diff(struct Curl_multi *multi,
           return CURLM_OUT_OF_MEMORY;
       }
       CURL_TRC_M(data, "ev entry fd=%" FMT_SOCKET_T ", added %s #%" FMT_OFF_T
-                 ", total=%u/%d (xfer/conn)", s,
+                 ", total=%" PRIu32 "/%d (xfer/conn)", s,
                  conn ? "connection" : "transfer",
                  conn ? conn->connection_id : data->mid,
                  Curl_uint32_spbset_count(&entry->xfers),
@@ -418,7 +411,7 @@ static CURLMcode mev_pollset_diff(struct Curl_multi *multi,
       if(mresult)
         return mresult;
       CURL_TRC_M(data, "ev entry fd=%" FMT_SOCKET_T ", removed transfer, "
-                 "total=%u/%d (xfer/conn)", s,
+                 "total=%" PRIu32 "/%d (xfer/conn)", s,
                  Curl_uint32_spbset_count(&entry->xfers),
                  entry->conn ? 1 : 0);
     }
@@ -588,7 +581,8 @@ void Curl_multi_ev_dirty_xfers(struct Curl_multi *multi,
           Curl_multi_mark_dirty(data);
         }
         else {
-          CURL_TRC_M(multi->admin, "socket transfer %u no longer found", mid);
+          CURL_TRC_M(multi->admin,
+                     "socket transfer %" PRIu32 " no longer found", mid);
           Curl_uint32_spbset_remove(&entry->xfers, mid);
         }
       } while(Curl_uint32_spbset_next(&entry->xfers, mid, &mid));
